#line 2 "libcoda/coda-expr-tokenizer.c"

#line 4 "libcoda/coda-expr-tokenizer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer coda_expression__create_buffer
#define yy_delete_buffer coda_expression__delete_buffer
#define yy_flex_debug coda_expression__flex_debug
#define yy_init_buffer coda_expression__init_buffer
#define yy_flush_buffer coda_expression__flush_buffer
#define yy_load_buffer_state coda_expression__load_buffer_state
#define yy_switch_to_buffer coda_expression__switch_to_buffer
#define yyin coda_expression_in
#define yyleng coda_expression_leng
#define yylex coda_expression_lex
#define yylineno coda_expression_lineno
#define yyout coda_expression_out
#define yyrestart coda_expression_restart
#define yytext coda_expression_text
#define yywrap coda_expression_wrap
#define yyalloc coda_expression_alloc
#define yyrealloc coda_expression_realloc
#define yyfree coda_expression_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE coda_expression_restart(coda_expression_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int coda_expression_leng;

extern FILE *coda_expression_in, *coda_expression_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up coda_expression_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up coda_expression_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via coda_expression_restart()), so that the user can continue scanning by
	 * just pointing coda_expression_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when coda_expression_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int coda_expression_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow coda_expression_wrap()'s to do buffer switches
 * instead of setting up a fresh coda_expression_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void coda_expression_restart (FILE *input_file  );
void coda_expression__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE coda_expression__create_buffer (FILE *file,int size  );
void coda_expression__delete_buffer (YY_BUFFER_STATE b  );
void coda_expression__flush_buffer (YY_BUFFER_STATE b  );
void coda_expression_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void coda_expression_pop_buffer_state (void );

static void coda_expression_ensure_buffer_stack (void );
static void coda_expression__load_buffer_state (void );
static void coda_expression__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER coda_expression__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE coda_expression__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE coda_expression__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE coda_expression__scan_bytes (yyconst char *bytes,int len  );

void *coda_expression_alloc (yy_size_t  );
void *coda_expression_realloc (void *,yy_size_t  );
void coda_expression_free (void *  );

#define yy_new_buffer coda_expression__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        coda_expression_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            coda_expression__create_buffer(coda_expression_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        coda_expression_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            coda_expression__create_buffer(coda_expression_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define coda_expression_wrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *coda_expression_in = (FILE *) 0, *coda_expression_out = (FILE *) 0;

typedef int yy_state_type;

extern int coda_expression_lineno;

int coda_expression_lineno = 1;

extern char *coda_expression_text;
#define yytext_ptr coda_expression_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up coda_expression_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	coda_expression_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 74
#define YY_END_OF_BUFFER 75
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[274] =
    {   0,
        0,    0,   75,   73,   72,   72,   10,   73,    6,   73,
       70,   73,   73,   73,   69,   69,   69,   69,   69,   69,
       69,   69,   68,   68,   69,   69,   69,   69,   12,   69,
       69,   69,   69,    7,   72,    5,    0,    1,    0,    8,
       11,   71,   71,   70,    0,    3,    4,    2,   69,   69,
       69,   69,   69,   25,   69,   69,   69,   69,   69,   69,
       14,   69,   69,   69,   69,   69,   69,   41,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   69,   69,   17,   69,   69,   69,    9,    0,   71,
        0,   71,   22,   23,   24,   69,   69,   69,   69,   69,

       69,   34,   69,   69,   69,   69,   15,   69,   69,   19,
       43,   69,   69,   69,   69,   69,   69,   52,   53,   18,
       69,   69,   69,   69,   69,   69,   61,   69,   69,   69,
       69,   69,   69,    0,   71,   69,   69,   69,   28,   69,
       32,   69,   69,   69,   69,   69,   69,   40,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   16,   69,   69,   64,   65,   20,   69,   67,   69,
       69,   69,   69,   29,   33,   69,   21,   69,   69,   38,
       39,   42,   45,   69,   44,   69,   69,   49,   69,   69,
       69,   58,   59,   60,   69,   69,   69,   69,   69,   69,

       69,   69,   35,   69,   69,   69,   69,   48,   69,   69,
       69,   69,   63,   69,   69,   69,   27,   69,   69,   69,
       69,   69,   69,   50,   69,   69,   62,   69,   69,   69,
       69,   31,   36,   37,   47,   69,   69,   69,   69,   69,
       69,   69,   13,   26,   69,   46,   69,   69,   69,   69,
       69,   69,   30,   69,   69,   69,   69,   69,   69,   51,
       69,   69,   56,   69,   69,   54,   69,   69,   66,   55,
       69,   57,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    1,    1,
        1,    1,    7,    1,    7,    8,    1,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    1,    1,   10,
       11,   12,    1,    1,   13,   13,   13,   13,   14,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
        1,   15,    1,    1,   16,    1,   17,   18,   19,   20,

       21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
       31,   32,   13,   33,   34,   35,   36,   37,   38,   39,
       40,   41,    1,   42,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[43] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
        1,    1,    2,    2,    1,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    1
    } ;

static yyconst flex_int16_t yy_base[276] =
    {   0,
        0,    0,  306,  307,   41,   43,  294,   42,  298,   40,
       42,  292,  291,  290,    0,   34,   30,   43,   28,  261,
       48,  268,   50,    0,   46,   41,   54,  265,   54,   42,
       61,  267,  271,  253,   80,  307,   82,  307,  291,  307,
      307,   79,   82,   90,   98,  307,  307,  307,    0,  259,
      272,  263,  271,    0,  254,  257,  252,  261,  249,  255,
        0,  258,  254,  253,  249,  246,  243,    0,   86,   84,
      247,  243,  236,  244,  243,  243,  240,  247,  233,  235,
       89,  249,  237,    0,   76,  247,  229,  307,  108,  109,
      254,  253,    0,    0,    0,  236,   93,  232,  238,  230,

      227,    0,  222,  221,  233,  102,    0,  222,  231,    0,
        0,  221,  225,  232,  220,  224,  221,    0,    0,    0,
      105,  225,  223,  213,  217,  209,  205,  205,  217,  208,
      215,  204,  210,  224,  223,  206,  208,  204,    0,   97,
        0,  193,  192,  205,  102,  190,  191,    0,  184,  200,
      191,  190,  183,  183,  188,  191,  187,  178,  174,  192,
      182,    0,  185,  174,    0,    0,    0,  172,    0,  179,
      184,  164,  182,  178,    0,  168,    0,  184,  175,    0,
        0,    0,    0,  174,    0,  164,  173,    0,  167,  174,
      175,    0,    0,    0,  164,  159,  161,  165,  155,  167,

      165,  145,    0,  156,  143,  153,  157,    0,  147,  151,
      144,  157,    0,  157,  146,  154,    0,  140,  152,  151,
      150,  148,  139,    0,  147,  115,    0,  142,  145,  130,
      143,    0,    0,    0,    0,  141,  132,  133,  129,  119,
      137,  127,    0,    0,  121,    0,  120,  134,  116,  116,
      114,  126,    0,  111,  110,  114,  121,  107,  119,    0,
      105,  121,    0,  110,   90,    0,   85,   71,    0,    0,
       65,    0,  307,  152,   58
    } ;

static yyconst flex_int16_t yy_def[276] =
    {   0,
      273,    1,  273,  273,  273,  273,  273,  274,  273,  273,
      273,  273,  273,  273,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  273,  273,  273,  274,  273,  274,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  273,  273,  273,
      273,  273,  275,  275,  275,  275,  275,  275,  275,  275,

      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  273,  273,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,

      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,    0,  273,  273
    } ;

static yyconst flex_int16_t yy_nxt[350] =
    {   0,
        4,    5,    6,    7,    8,    9,    4,   10,   11,   12,
       13,   14,   15,   15,    4,    4,   16,   17,   18,   19,
       20,   21,   22,   15,   23,   24,   24,   25,   26,   27,
       15,   28,   29,   30,   31,   32,   15,   33,   15,   15,
       15,   34,   35,   35,   35,   35,   38,   41,   42,   43,
       44,   50,   60,   51,   55,   45,   39,   73,   61,   49,
       56,   52,   45,   58,   63,   74,   71,   53,   54,   57,
       75,   68,   64,   59,   78,   65,   81,   82,   66,   69,
       72,   35,   35,   70,   79,   83,   38,   42,   80,   76,
       90,   84,   89,   85,  272,   89,   39,   43,   44,   89,

      130,  271,   89,   45,   91,  109,   92,  110,  112,  126,
       45,  131,  113,  114,  134,  115,  135,   90,  146,  270,
      111,  127,   89,  137,  156,  157,  138,  173,  269,   89,
      174,  178,  147,  238,  268,  179,  239,  267,  266,  265,
      264,  263,  262,  261,  260,  259,  258,  257,  256,  240,
      255,  241,   37,   37,  254,  253,  252,  251,  250,  249,
      248,  247,  246,  245,  244,  243,  242,  237,  236,  235,
      234,  233,  232,  231,  230,  229,  228,  227,  226,  225,
      224,  223,  222,  221,  220,  219,  218,  217,  216,  215,
      214,  213,  212,  211,  210,  209,  208,  207,  206,  205,

      204,  203,  202,  201,  200,  199,  198,  197,  196,  195,
      194,  193,  192,  191,  190,  189,  188,  187,  186,  185,
      184,  183,  182,  181,  180,  177,  176,  175,  172,  171,
      170,  135,  135,  169,  168,  167,  166,  165,  164,  163,
      162,  161,  160,  159,  158,  155,  154,  153,  152,  151,
      150,  149,  148,  145,  144,  143,  142,  141,  140,  139,
      136,   92,   92,  133,  132,  129,  128,  125,  124,  123,
      122,  121,  120,  119,  118,  117,  116,  108,  107,  106,
      105,  104,  103,  102,  101,  100,   99,   98,   97,   96,
       95,   94,   93,  273,   88,   87,   86,   77,   67,   62,

       48,   47,   46,   40,   36,  273,    3,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273
    } ;

static yyconst flex_int16_t yy_chk[350] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    5,    6,    6,    8,   10,   10,   11,
       11,   16,   19,   16,   17,   11,    8,   26,   19,  275,
       17,   16,   11,   18,   21,   26,   25,   16,   16,   17,
       27,   23,   21,   18,   29,   21,   30,   30,   21,   23,
       25,   35,   35,   23,   29,   31,   37,   42,   29,   27,
       43,   31,   42,   31,  271,   43,   37,   44,   44,   42,

       85,  268,   43,   44,   45,   69,   45,   69,   70,   81,
       44,   85,   70,   70,   89,   70,   89,   90,  106,  267,
       69,   81,   90,   97,  121,  121,   97,  140,  265,   90,
      140,  145,  106,  226,  264,  145,  226,  262,  261,  259,
      258,  257,  256,  255,  254,  252,  251,  250,  249,  226,
      248,  226,  274,  274,  247,  245,  242,  241,  240,  239,
      238,  237,  236,  231,  230,  229,  228,  225,  223,  222,
      221,  220,  219,  218,  216,  215,  214,  212,  211,  210,
      209,  207,  206,  205,  204,  202,  201,  200,  199,  198,
      197,  196,  195,  191,  190,  189,  187,  186,  184,  179,

      178,  176,  174,  173,  172,  171,  170,  168,  164,  163,
      161,  160,  159,  158,  157,  156,  155,  154,  153,  152,
      151,  150,  149,  147,  146,  144,  143,  142,  138,  137,
      136,  135,  134,  133,  132,  131,  130,  129,  128,  127,
      126,  125,  124,  123,  122,  117,  116,  115,  114,  113,
      112,  109,  108,  105,  104,  103,  101,  100,   99,   98,
       96,   92,   91,   87,   86,   83,   82,   80,   79,   78,
       77,   76,   75,   74,   73,   72,   71,   67,   66,   65,
       64,   63,   62,   60,   59,   58,   57,   56,   55,   53,
       52,   51,   50,   39,   34,   33,   32,   28,   22,   20,

       14,   13,   12,    9,    7,    3,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int coda_expression__flex_debug;
int coda_expression__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *coda_expression_text;
#line 1 "../coda/libcoda/coda-expr-tokenizer.l"
/*
 * Copyright (C) 2007-2017 S[&]T, The Netherlands.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
/* *INDENT-OFF* */
#define YY_NO_INPUT 1
#line 41 "../coda/libcoda/coda-expr-tokenizer.l"
#include "coda-expr.h"

#include <math.h>
#include <stdlib.h>
#include <string.h>

#include "coda-expr-parser.h"
#line 686 "libcoda/coda-expr-tokenizer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int coda_expression_lex_destroy (void );

int coda_expression_get_debug (void );

void coda_expression_set_debug (int debug_flag  );

YY_EXTRA_TYPE coda_expression_get_extra (void );

void coda_expression_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *coda_expression_get_in (void );

void coda_expression_set_in  (FILE * in_str  );

FILE *coda_expression_get_out (void );

void coda_expression_set_out  (FILE * out_str  );

int coda_expression_get_leng (void );

char *coda_expression_get_text (void );

int coda_expression_get_lineno (void );

void coda_expression_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int coda_expression_wrap (void );
#else
extern int coda_expression_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( coda_expression_text, coda_expression_leng, 1, coda_expression_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( coda_expression_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( coda_expression_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, coda_expression_in))==0 && ferror(coda_expression_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(coda_expression_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int coda_expression_lex (void);

#define YY_DECL int coda_expression_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after coda_expression_text and coda_expression_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 59 "../coda/libcoda/coda-expr-tokenizer.l"


#line 874 "libcoda/coda-expr-tokenizer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! coda_expression_in )
			coda_expression_in = stdin;

		if ( ! coda_expression_out )
			coda_expression_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			coda_expression_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				coda_expression__create_buffer(coda_expression_in,YY_BUF_SIZE );
		}

		coda_expression__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of coda_expression_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 274 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 307 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 61 "../coda/libcoda/coda-expr-tokenizer.l"
{
                            yylval.stringval = (char *)malloc(coda_expression_leng - 1);
                            memcpy(yylval.stringval, coda_expression_text + 1, coda_expression_leng - 2);
                            yylval.stringval[coda_expression_leng - 2] = '\0';
                            return STRING_VALUE;
                        }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 68 "../coda/libcoda/coda-expr-tokenizer.l"
return GREATER_EQUAL;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 69 "../coda/libcoda/coda-expr-tokenizer.l"
return LESS_EQUAL;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 70 "../coda/libcoda/coda-expr-tokenizer.l"
return EQUAL;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 71 "../coda/libcoda/coda-expr-tokenizer.l"
return NOT_EQUAL;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 72 "../coda/libcoda/coda-expr-tokenizer.l"
return AND;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 73 "../coda/libcoda/coda-expr-tokenizer.l"
return OR;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 74 "../coda/libcoda/coda-expr-tokenizer.l"
return LOGICAL_AND;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 75 "../coda/libcoda/coda-expr-tokenizer.l"
return LOGICAL_OR;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 76 "../coda/libcoda/coda-expr-tokenizer.l"
return NOT;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 77 "../coda/libcoda/coda-expr-tokenizer.l"
return GOTO_PARENT;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 79 "../coda/libcoda/coda-expr-tokenizer.l"
return RAW_PREFIX;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 80 "../coda/libcoda/coda-expr-tokenizer.l"
return ASCIILINE;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 81 "../coda/libcoda/coda-expr-tokenizer.l"
return DO;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 82 "../coda/libcoda/coda-expr-tokenizer.l"
return FOR;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 83 "../coda/libcoda/coda-expr-tokenizer.l"
return STEP;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 84 "../coda/libcoda/coda-expr-tokenizer.l"
return TO;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 85 "../coda/libcoda/coda-expr-tokenizer.l"
return NAN_VALUE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 86 "../coda/libcoda/coda-expr-tokenizer.l"
return INF_VALUE;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 87 "../coda/libcoda/coda-expr-tokenizer.l"
return TRUE_VALUE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 88 "../coda/libcoda/coda-expr-tokenizer.l"
return FALSE_VALUE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 89 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ABS;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 90 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ADD;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 91 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ALL;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 92 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_AT;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 93 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_BITOFFSET;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 94 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_BITSIZE;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 95 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_BOOL;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 96 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_BYTES;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 97 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_BYTEOFFSET;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 98 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_BYTESIZE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 99 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_CEIL;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 100 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_COUNT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 101 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_DIM;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 102 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_EXISTS;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 103 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_FILENAME;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 104 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_FILESIZE;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 105 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_FLOAT;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 106 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_FLOOR;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 107 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_GOTO;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 108 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_IF;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 109 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_INDEX;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 110 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_INT;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 111 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ISNAN;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 112 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ISINF;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 113 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ISPLUSINF;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 114 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ISMININF;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 115 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_LENGTH;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 116 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_LTRIM;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 117 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_NUMDIMS;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 118 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_NUMELEMENTS;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 119 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_MAX;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 120 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_MIN;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 121 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_PRODUCTCLASS;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 122 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_PRODUCTFORMAT;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 123 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_PRODUCTTYPE;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 124 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_PRODUCTVERSION;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 125 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_REGEX;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 126 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_ROUND;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 127 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_RTRIM;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 128 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_STR;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 129 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_STRTIME;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 130 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_SUBSTR;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 131 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_TIME;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 132 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_TRIM;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 133 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_UNBOUNDINDEX;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 134 "../coda/libcoda/coda-expr-tokenizer.l"
return FUNC_WITH;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 136 "../coda/libcoda/coda-expr-tokenizer.l"
{
                            yylval.stringval = strdup(coda_expression_text);
                            return INDEX_VAR;
                        }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 140 "../coda/libcoda/coda-expr-tokenizer.l"
{
                            yylval.stringval = strdup(coda_expression_text);
                            return NAME;
                        }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 144 "../coda/libcoda/coda-expr-tokenizer.l"
{
                            yylval.stringval = strdup(coda_expression_text);                            
                            return INT_VALUE;
                        }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 148 "../coda/libcoda/coda-expr-tokenizer.l"
{
                            yylval.stringval = strdup(coda_expression_text);                            
                            return FLOAT_VALUE;
                        }
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 152 "../coda/libcoda/coda-expr-tokenizer.l"
/* eat whitespace */
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 153 "../coda/libcoda/coda-expr-tokenizer.l"
return (*coda_expression_text);
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 155 "../coda/libcoda/coda-expr-tokenizer.l"
ECHO;
	YY_BREAK
#line 1346 "libcoda/coda-expr-tokenizer.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed coda_expression_in at a new source and called
			 * coda_expression_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = coda_expression_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( coda_expression_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * coda_expression_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of coda_expression_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					coda_expression_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			coda_expression_restart(coda_expression_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) coda_expression_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 274 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 274 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 273);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					coda_expression_restart(coda_expression_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( coda_expression_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve coda_expression_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void coda_expression_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        coda_expression_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            coda_expression__create_buffer(coda_expression_in,YY_BUF_SIZE );
	}

	coda_expression__init_buffer(YY_CURRENT_BUFFER,input_file );
	coda_expression__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void coda_expression__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		coda_expression_pop_buffer_state();
	 *		coda_expression_push_buffer_state(new_buffer);
     */
	coda_expression_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	coda_expression__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (coda_expression_wrap()) processing, but the only time this flag
	 * is looked at is after coda_expression_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void coda_expression__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	coda_expression_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE coda_expression__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) coda_expression_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in coda_expression__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) coda_expression_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in coda_expression__create_buffer()" );

	b->yy_is_our_buffer = 1;

	coda_expression__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with coda_expression__create_buffer()
 * 
 */
    void coda_expression__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		coda_expression_free((void *) b->yy_ch_buf  );

	coda_expression_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a coda_expression_restart() or at EOF.
 */
    static void coda_expression__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	coda_expression__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then coda_expression__init_buffer was _probably_
     * called from coda_expression_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 1;

	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void coda_expression__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		coda_expression__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void coda_expression_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	coda_expression_ensure_buffer_stack();

	/* This block is copied from coda_expression__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from coda_expression__switch_to_buffer. */
	coda_expression__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void coda_expression_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	coda_expression__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		coda_expression__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void coda_expression_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)coda_expression_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in coda_expression_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)coda_expression_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in coda_expression_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE coda_expression__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) coda_expression_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in coda_expression__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	coda_expression__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to coda_expression_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       coda_expression__scan_bytes() instead.
 */
YY_BUFFER_STATE coda_expression__scan_string (yyconst char * yystr )
{
    
	return coda_expression__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to coda_expression_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE coda_expression__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) coda_expression_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in coda_expression__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = coda_expression__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in coda_expression__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up coda_expression_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		coda_expression_text[coda_expression_leng] = (yy_hold_char); \
		(yy_c_buf_p) = coda_expression_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		coda_expression_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int coda_expression_get_lineno  (void)
{
        
    return coda_expression_lineno;
}

/** Get the input stream.
 * 
 */
FILE *coda_expression_get_in  (void)
{
        return coda_expression_in;
}

/** Get the output stream.
 * 
 */
FILE *coda_expression_get_out  (void)
{
        return coda_expression_out;
}

/** Get the length of the current token.
 * 
 */
int coda_expression_get_leng  (void)
{
        return coda_expression_leng;
}

/** Get the current token.
 * 
 */

char *coda_expression_get_text  (void)
{
        return coda_expression_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void coda_expression_set_lineno (int  line_number )
{
    
    coda_expression_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see coda_expression__switch_to_buffer
 */
void coda_expression_set_in (FILE *  in_str )
{
        coda_expression_in = in_str ;
}

void coda_expression_set_out (FILE *  out_str )
{
        coda_expression_out = out_str ;
}

int coda_expression_get_debug  (void)
{
        return coda_expression__flex_debug;
}

void coda_expression_set_debug (int  bdebug )
{
        coda_expression__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from coda_expression_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    coda_expression_in = stdin;
    coda_expression_out = stdout;
#else
    coda_expression_in = (FILE *) 0;
    coda_expression_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * coda_expression_lex_init()
     */
    return 0;
}

/* coda_expression_lex_destroy is for both reentrant and non-reentrant scanners. */
int coda_expression_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		coda_expression__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		coda_expression_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	coda_expression_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * coda_expression_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *coda_expression_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *coda_expression_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void coda_expression_free (void * ptr )
{
	free( (char *) ptr );	/* see coda_expression_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 155 "../coda/libcoda/coda-expr-tokenizer.l"



